/*
 * Copyright (c) 2000 Jacek Prucia
 * 
 * Written by Jacek Prucia while at 7bulls.com
 * 
 * You may distribute under the terms of the GNU General Public License as
 * specified in the README file that comes with the CVS source distribution.
 *
 */


#include "cvs.h"
#include "getline.h"

/* cvs bookmark filename */

void strip_whitespaces (char *string);
extern char *strtok ();

char cvsbookmarks[] = ".cvsbookmarks";

/* Read .cvsbmark, parsing repository bookmarks */

char *
parse_cvsbookmarks (cvs_bookmark)
	char *cvs_bookmark;
{
    char *homedir;
    char *cvsbookmarkpath;
    FILE *cvsbookmarkfile;

    char *line;
    int line_length;
    size_t line_chars_allocated;

    int bookmark_found;
    int bookmark_length;
    char *bookmark_name;
    char *bookmark_repository;

    /* determine absolute path for .cvsbookmarks file */
    homedir = get_homedir ();
    
	if (!homedir) {
		return NULL;
	}

    cvsbookmarkpath = (char *) xmalloc (strlen (homedir) + strlen (cvsbookmarks) + 10);
    strcpy (cvsbookmarkpath, homedir);
    strcpy (strchr (cvsbookmarkpath, '\0'), "/");
    strcpy (strchr (cvsbookmarkpath, '\0'), cvsbookmarks);

    /* can we read the file? */
    if (!isreadable (cvsbookmarkpath))
    {
	free (cvsbookmarkpath);
	return NULL;
    }

    /* parse file... */

    line = NULL;
    line_chars_allocated = 0;
    bookmark_found = 0;

    cvsbookmarkfile = open_file (cvsbookmarkpath, "r");
    while ((line_length = getline (&line, &line_chars_allocated, cvsbookmarkfile))
	   >= 0)
    {
	/* skip over comment lines */
	if (line[0] == '#')
	    continue;

	/* strip off all white spaces */
	strip_whitespaces (line);
	
	/* check current line for bookmark...
	 * if there's no '=' simply just ignore it... */

	bookmark_name = strtok(line, "=");
	
	if (bookmark_name != NULL) {

		/* check bookmark against supplied argument */
		if (!strcmp(cvs_bookmark, bookmark_name)) {
			
			bookmark_repository = strtok (NULL, "=");
			bookmark_length = strlen (bookmark_repository);
			if (bookmark_repository[--bookmark_length] == '\n') {
				bookmark_repository[bookmark_length] = '\0';
			}
			bookmark_found = 1;
			break;
		}
	}

    }

    if (line_length < 0 && !feof (cvsbookmarkfile))
	error (0, errno, "cannot read %s", cvsbookmarkpath);

    fclose (cvsbookmarkfile);
    free (cvsbookmarkpath);

    /* time to return... */

    return bookmark_found ? xstrdup(bookmark_repository) : NULL;

}

void strip_whitespaces (string)
	char* string;
{

	int i, j = 0;
	int stringlen = strlen(string);

	for (i = 0; i < stringlen; i++) {
		if (isgraph(string[i])) {
			string[j++] = string[i];
		}
	}
	string[j] = '\0';
			
	
}

